## Checklist de validação

- [ ] Testei as mudanças localmente e verifiquei que tudo está funcionando conforme esperado
- [ ] Incluí testes para as mudanças (ou verifiquei que não se aplicam neste caso)
- [ ] Atualizei a documentação (README, comentários, exemplos, etc.) se necessário
- [ ] Meu código segue as diretrizes de estilo do projeto e realizei uma auto-revisão
- [ ] Não há novos erros ou warnings nos logs ou no output do compilador/linter

## Descrição do problema

<!-- Descreva aqui o problema que sua contribuição resolve. -->
<!-- Se houver uma issue relacionada, cite-a usando "Resolve #Número_da_Issue". -->
Explique de forma clara qual é o problema ou necessidade que motivou este Pull Request. Detalhe **o que** estava errado ou faltando, e **por que** isso deveria ser resolvido.

## Descrição da solução

<!-- Descreva aqui as mudanças que você fez. -->
Detalhe as modificações realizadas no código para resolver o problema acima. Explique **como** sua solução resolve o problema e mencione quaisquer abordagens alternativas que você tenha considerado. Se houver impactos em outras partes do projeto, descreva-os aqui.

<!-- Opcional: você também pode adicionar uma seção de "Notas para o revisor" ou "Informações adicionais" se achar necessário. -->